==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/blockchain/kotlin/inputs/GetTransactionNodePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.blockchain.kotlin.inputs

import com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property blockchainMemberName Blockchain member name.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property transactionNodeName Transaction node name.
 */
public data class GetTransactionNodePlainArgs(
    public val blockchainMemberName: String,
    public val resourceGroupName: String,
    public val transactionNodeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs =
        com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs.builder()
            .blockchainMemberName(blockchainMemberName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .transactionNodeName(transactionNodeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTransactionNodePlainArgs].
 */
@PulumiTagMarker
public class GetTransactionNodePlainArgsBuilder internal constructor() {
    private var blockchainMemberName: String? = null

    private var resourceGroupName: String? = null

    private var transactionNodeName: String? = null

    /**
     * @param value Blockchain member name.
     */
    @JvmName("qeavvqdepmneqhxo")
    public suspend fun blockchainMemberName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.blockchainMemberName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("xpdhlyyhetsullri")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Transaction node name.
     */
    @JvmName("xojerkcsinsxefgj")
    public suspend fun transactionNodeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.transactionNodeName = mapped
    }

    internal fun build(): GetTransactionNodePlainArgs = GetTransactionNodePlainArgs(
        blockchainMemberName = blockchainMemberName ?: throw
            PulumiNullFieldException("blockchainMemberName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        transactionNodeName = transactionNodeName ?: throw PulumiNullFieldException("transactionNodeName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/blockchain/kotlin/inputs/GetTransactionNodePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.blockchain.kotlin.inputs

import com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property blockchainMemberName Blockchain member name.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property transactionNodeName Transaction node name.
 */
public data class GetTransactionNodePlainArgs(
    public val blockchainMemberName: String,
    public val resourceGroupName: String,
    public val transactionNodeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs =
        com.pulumi.azurenative.blockchain.inputs.GetTransactionNodePlainArgs.builder()
            .blockchainMemberName(blockchainMemberName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .transactionNodeName(transactionNodeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTransactionNodePlainArgs].
 */
@PulumiTagMarker
public class GetTransactionNodePlainArgsBuilder internal constructor() {
    private var blockchainMemberName: String? = null

    private var resourceGroupName: String? = null

    private var transactionNodeName: String? = null

    /**
     * @param value Blockchain member name.
     */
    @JvmName("wqtunmunhkbofhrx")
    public suspend fun blockchainMemberName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.blockchainMemberName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("tshhkeoutsebvwfq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Transaction node name.
     */
    @JvmName("yhjhkudtgekiatfh")
    public suspend fun transactionNodeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.transactionNodeName = mapped
    }

    internal fun build(): GetTransactionNodePlainArgs = GetTransactionNodePlainArgs(
        blockchainMemberName = blockchainMemberName ?: throw
            PulumiNullFieldException("blockchainMemberName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        transactionNodeName = transactionNodeName ?: throw PulumiNullFieldException("transactionNodeName"),
    )
}
